Linux workstation

Fedora 44 native package

cubeb-devel

A cross platform audio library

Packages / Fedora 44 / Unspecified / cubeb-devel

[Source: cubeb]

Package: cubeb-devel (0.2-20.20230517.git48689ae.fc44)

[Project overview: cubeb]

External Resources:

Homepage: [github.com]

A cross platform audio library

Cubeb is a cross-platform library, written in C/C++, that was created and has been maintained by the Firefox Media Team. The role of the library is to communicate with audio devices and to provide audio input and/or output.

Other Packages Related to cubeb-devel:

  • dep: cmake-filesystem(aarch-64)

    Package not available

  • dep: ld-linux-aarch64.so.1()(64bit)

    Package not available

  • dep: ld-linux-aarch64.so.1(GLIBC_2.17)(64bit)

    Package not available

  • dep: libm.so.6()(64bit)

    Package not available

  • dep: libm.so.6(GLIBC_2.17)(64bit)

    Package not available

  • dep: libstdc++.so.6()(64bit)

    Package not available

  • dep: libstdc++.so.6(CXXABI_1.3)(64bit)

    Package not available

  • dep: libstdc++.so.6(GLIBCXX_3.4)(64bit)

    Package not available

  • dep: libstdc++.so.6(GLIBCXX_3.4.11)(64bit)

    Package not available

  • dep: libstdc++.so.6(GLIBCXX_3.4.22)(64bit)

    Package not available

  • dep: libstdc++.so.6(GLIBCXX_3.4.32)(64bit)

    Package not available

  • dep: libstdc++.so.6(GLIBCXX_3.4.9)(64bit)

    Package not available

  • dep: rtld(GNU_HASH)

    Package not available

  • dep: libc.so.6(GLIBC_2.38)(64bit)

    Package not available

Download cubeb-devel

ArchitecturePackage SizeInstalled SizeFiles
aarch64520 KiB2.6 MiB[list of files]
i686530 KiB2.0 MiB[list of files]
x86_64540 KiB2.6 MiB[list of files]

Percorsi file del pacchetto (112)

Paths come from the repository package-file index for the observed builds. They describe archive/package associations, not every file that will exist on a running system after maintainer scripts, alternatives, generated state, diversions, or installation choices.

  • /usr/bin/cubeb-test
  • /usr/include/cubeb
  • /usr/include/cubeb/cubeb_export.h
  • /usr/include/cubeb/cubeb.h
  • /usr/lib64/cmake/cubeb
  • /usr/lib64/cmake/cubeb/cubebConfig.cmake
  • /usr/lib64/cmake/cubeb/cubebConfigVersion.cmake
  • /usr/lib64/cmake/cubeb/cubebTargets.cmake
  • /usr/lib64/cmake/cubeb/cubebTargets-relwithdebinfo.cmake
  • /usr/lib64/libcubeb.a
  • /usr/lib/.build-id
  • /usr/lib/.build-id/16
  • /usr/lib/.build-id/16/40343e464f20240a486e581cb42f6dd36c2fde
  • /usr/lib/.build-id/23
  • /usr/lib/.build-id/23/b9e95f51135c4d2bc9d3543c065e563d8e330e
  • /usr/lib/.build-id/50
  • /usr/lib/.build-id/50/855356448e90337dd92a571530567f9022b770
  • /usr/lib/cmake/cubeb
  • /usr/lib/cmake/cubeb/cubebConfig.cmake
  • /usr/lib/cmake/cubeb/cubebConfigVersion.cmake
  • /usr/lib/cmake/cubeb/cubebTargets.cmake
  • /usr/lib/cmake/cubeb/cubebTargets-relwithdebinfo.cmake
  • /usr/lib/libcubeb.a
  • /usr/share/doc/cubeb
  • /usr/share/doc/cubeb/annotated_dup.js
  • /usr/share/doc/cubeb/annotated.html
  • /usr/share/doc/cubeb/classes.html
  • /usr/share/doc/cubeb/clipboard.js
  • /usr/share/doc/cubeb/cookie.js
  • /usr/share/doc/cubeb/cubeb_8h.html
  • /usr/share/doc/cubeb/cubeb_8h.js
  • /usr/share/doc/cubeb/cubeb_8h_source.html
  • /usr/share/doc/cubeb-devel
  • /usr/share/doc/cubeb-devel/README.md
  • /usr/share/doc/cubeb/dir_4a77ea686d101b1caa0240510cb36860.html
  • /usr/share/doc/cubeb/dir_4a77ea686d101b1caa0240510cb36860.js
  • /usr/share/doc/cubeb/dir_d44c64559bbebec7f509842c48db8b23.html
  • /usr/share/doc/cubeb/dir_d44c64559bbebec7f509842c48db8b23.js
  • /usr/share/doc/cubeb/doxygen_crawl.html
  • /usr/share/doc/cubeb/doxygen.css
  • /usr/share/doc/cubeb/doxygen.svg
  • /usr/share/doc/cubeb/dynsections.js
  • /usr/share/doc/cubeb/files_dup.js
  • /usr/share/doc/cubeb/files.html
  • /usr/share/doc/cubeb/functions.html
  • /usr/share/doc/cubeb/functions_vars.html
  • /usr/share/doc/cubeb/globals_defs.html
  • /usr/share/doc/cubeb/globals_enum.html
  • /usr/share/doc/cubeb/globals_eval.html
  • /usr/share/doc/cubeb/globals_func.html
  • /usr/share/doc/cubeb/globals.html
  • /usr/share/doc/cubeb/globals_type.html
  • /usr/share/doc/cubeb/index.html
  • /usr/share/doc/cubeb/jquery.js
  • /usr/share/doc/cubeb/menudata.js
  • /usr/share/doc/cubeb/menu.js
  • /usr/share/doc/cubeb/navtree.css
  • /usr/share/doc/cubeb/navtreedata.js
  • /usr/share/doc/cubeb/navtreeindex0.js
  • /usr/share/doc/cubeb/navtree.js
  • /usr/share/doc/cubeb/search
  • /usr/share/doc/cubeb/search/all_0.js
  • /usr/share/doc/cubeb/search/all_1.js
  • /usr/share/doc/cubeb/search/all_2.js
  • /usr/share/doc/cubeb/search/all_3.js
  • /usr/share/doc/cubeb/search/all_4.js
  • /usr/share/doc/cubeb/search/all_5.js
  • /usr/share/doc/cubeb/search/all_6.js
  • /usr/share/doc/cubeb/search/all_7.js
  • /usr/share/doc/cubeb/search/all_8.js
  • /usr/share/doc/cubeb/search/all_9.js
  • /usr/share/doc/cubeb/search/all_a.js
  • /usr/share/doc/cubeb/search/all_b.js
  • /usr/share/doc/cubeb/search/all_c.js
  • /usr/share/doc/cubeb/search/all_d.js
  • /usr/share/doc/cubeb/search/classes_0.js
  • /usr/share/doc/cubeb/search/defines_0.js
  • /usr/share/doc/cubeb/search/enums_0.js
  • /usr/share/doc/cubeb/search/enumvalues_0.js
  • /usr/share/doc/cubeb/search/files_0.js
  • /usr/share/doc/cubeb/search/functions_0.js
  • /usr/share/doc/cubeb/search/pages_0.js
  • /usr/share/doc/cubeb/search/pages_1.js
  • /usr/share/doc/cubeb/search/pages_2.js
  • /usr/share/doc/cubeb/search/search.css
  • /usr/share/doc/cubeb/search/searchdata.js
  • /usr/share/doc/cubeb/search/search.js
  • /usr/share/doc/cubeb/search/typedefs_0.js
  • /usr/share/doc/cubeb/search/variables_0.js
  • /usr/share/doc/cubeb/search/variables_1.js
  • /usr/share/doc/cubeb/search/variables_2.js
  • /usr/share/doc/cubeb/search/variables_3.js
  • /usr/share/doc/cubeb/search/variables_4.js
  • /usr/share/doc/cubeb/search/variables_5.js
  • /usr/share/doc/cubeb/search/variables_6.js
  • /usr/share/doc/cubeb/search/variables_7.js
  • /usr/share/doc/cubeb/search/variables_8.js
  • /usr/share/doc/cubeb/search/variables_9.js
  • /usr/share/doc/cubeb/search/variables_a.js
  • /usr/share/doc/cubeb/search/variables_b.js
  • /usr/share/doc/cubeb/search/variables_c.js
  • /usr/share/doc/cubeb/structcubeb__device__collection.html
  • /usr/share/doc/cubeb/structcubeb__device__collection.js
  • /usr/share/doc/cubeb/structcubeb__device.html
  • /usr/share/doc/cubeb/structcubeb__device__info.html
  • /usr/share/doc/cubeb/structcubeb__device__info.js
  • /usr/share/doc/cubeb/structcubeb__device.js
  • /usr/share/doc/cubeb/structcubeb__stream__params.html
  • /usr/share/doc/cubeb/structcubeb__stream__params.js
  • /usr/share/doc/cubeb/tabs.css
  • /usr/share/licenses/cubeb-devel
  • /usr/share/licenses/cubeb-devel/LICENSE

Field source: Fedora 44 Everything aarch64 revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee

Usa questo pacchetto

OpenFactory può avviare questo sistema operativo in una macchina virtuale del browser, o iniziare una costruzione che include il nome nativo del pacchetto di questo record.

Versioni, suite e repository

Ogni riga è metadato dell'indice pacchetti per una versione, architettura, suite e repository. Nomi, URL e dimensioni arrivano dalla fonte; un link è un punto di recupero mutabile, non una redistribuzione OpenFactory.

VersionReleaseArchitectureRepositoryPackage sizeInstalled sizePublisher repository artifact
0.2-20.20230517.git48689ae.fc4444 / everythingaarch64Fedora 44 · Everything · aarch64520 KiB2.6 MiBPackages/c/cubeb-devel-0.2-20.20230517.git48689ae.fc44.aarch64.rpm
0.2-20.20230517.git48689ae.fc4444 / everythingi686Fedora 44 · Everything · x86_64530 KiB2.0 MiBPackages/c/cubeb-devel-0.2-20.20230517.git48689ae.fc44.i686.rpm
0.2-20.20230517.git48689ae.fc4444 / everythingx86_64Fedora 44 · Everything · x86_64540 KiB2.6 MiBPackages/c/cubeb-devel-0.2-20.20230517.git48689ae.fc44.x86_64.rpm

Field source: Fedora 44 Everything aarch64 revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee

Checksum e date di osservazione

For an APT source, signature verification authenticates the repository metadata chain and the Packages index containing this source-reported artifact digest. It does not certify package safety.

0.2-20.20230517.git48689ae.fc44 / aarch64Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: e10612e487dd4db8f6bffa68e118b3958d1c562be16ab8d966b56b04f8055702

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'e10612e487dd4db8f6bffa68e118b3958d1c562be16ab8d966b56b04f8055702' 'cubeb-devel-0.2-20.20230517.git48689ae.fc44.aarch64.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 44 Everything aarch64 revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee

0.2-20.20230517.git48689ae.fc44 / i686Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: 51a8c38ef599cc4cee5804f45952efb4a0a797c7e09fe1a09573221aba72152e

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' '51a8c38ef599cc4cee5804f45952efb4a0a797c7e09fe1a09573221aba72152e' 'cubeb-devel-0.2-20.20230517.git48689ae.fc44.i686.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 44 Everything x86_64 revision 44-everything-x86_64:da3845427d188097f6fd71b417a039bdfb8efefc4f38ca44b5cbb94f95a18991

0.2-20.20230517.git48689ae.fc44 / x86_64Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: 8474762a7d30045472c7ee6fbf64f76d5ce6e934f1e4e16b687960d2c8784f8a

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' '8474762a7d30045472c7ee6fbf64f76d5ce6e934f1e4e16b687960d2c8784f8a' 'cubeb-devel-0.2-20.20230517.git48689ae.fc44.x86_64.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 44 Everything x86_64 revision 44-everything-x86_64:da3845427d188097f6fd71b417a039bdfb8efefc4f38ca44b5cbb94f95a18991

Completezza del record

The completeness score measures metadata coverage, not software quality, security, compatibility, or suitability.

Summary and description
25/25
Artifact path and source digest
25/25
Dependency metadata
15/15
Package-file index
15/15
Homepage
5/5
License text
5/5
Source package or maintainer
10/10

Recorded total: 100/100

Field source: Fedora 44 Everything aarch64 revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee, Fedora 44 Everything x86_64 revision 44-everything-x86_64:da3845427d188097f6fd71b417a039bdfb8efefc4f38ca44b5cbb94f95a18991. The cross-OS mapping is catalog-derived from the source-reported homepage; it does not establish authorship or publisher identity

Fonti e provenienza

Field-source links above resolve here. Each source entry names the metadata publisher, trust tier, exact snapshot revision, signature result, and observation time; catalog-derived mappings are labeled separately.

  • Authoritative source; repository metadata signature verified, revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    236514c32119ab3c85b81fbb9e5e9d92b07aeba0d19d64c9b4fc9117a1863769
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-44-primary
    SHA-256 93642aec521a1e5e96dd715f7ae0ec0850ebc9de09a94ce03cae5263f26cc18a
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

  • Authoritative source; repository metadata signature verified, revision 44-everything-x86_64:da3845427d188097f6fd71b417a039bdfb8efefc4f38ca44b5cbb94f95a18991

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    1300b99ac5d04b5561ad901320c8bd59ed1553f4971c3ce2ca48c40242c66676
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-44-primary
    SHA-256 93642aec521a1e5e96dd715f7ae0ec0850ebc9de09a94ce03cae5263f26cc18a
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

cubeb-devel Package for Fedora 44 | OpenFactory